ArticleComment class

文章评论

Constructors

ArticleComment({bool isNice = false, String createTimeStr = '', String authorId = '', String score = '', String createTime = '', String authorURL = '', VoteStatus vote = VoteStatus.normal, int revisionCount = 0, String timeAgo = '', String replyId = '', List<Metal> sysMetal = const [], int goodCnt = 0, bool visible = true, String articleId = '', int rewardedCnt = 0, String sharpURL = '', bool isAnonymous = false, int replyCnt = 0, String oId = '', String content = '', ArticleStatus status = ArticleStatus.Normal, String author = '', int thankCnt = 0, int badCnt = 0, bool rewarded = false, String thumbnailURL = '', String audioURL = '', int offered = 0, dynamic commenter})
ArticleComment.from(Map<String, dynamic> data)

Properties

articleId ↔ String
文章 id
getter/setter pair
audioURL ↔ String
评论音频地址
getter/setter pair
author ↔ String
评论作者用户名
getter/setter pair
authorId ↔ String
评论作者 id
getter/setter pair
authorURL ↔ String
评论作者头像
getter/setter pair
badCnt ↔ int
评论点踩数
getter/setter pair
commenter ↔ CommentAuthor
评论作者
getter/setter pair
content ↔ String
评论内容
getter/setter pair
createTime ↔ String
评论创建时间
getter/setter pair
createTimeStr ↔ String
评论创建时间字符串
getter/setter pair
goodCnt ↔ int
点赞数
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isAnonymous ↔ bool
是否匿名
getter/setter pair
isNice ↔ bool
是否优评
getter/setter pair
offered ↔ int
评论是否采纳,1 表示采纳
getter/setter pair
oId ↔ String
评论 id
getter/setter pair
replyCnt ↔ int
评论回复数
getter/setter pair
replyId ↔ String
回复评论 id
getter/setter pair
revisionCount ↔ int
评论引用数
getter/setter pair
rewarded ↔ bool
是否已感谢
getter/setter pair
rewardedCnt ↔ int
评论感谢数
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
score ↔ String
评论分数
getter/setter pair
sharpURL ↔ String
评论地址
getter/setter pair
status ↔ ArticleStatus
评论状态
getter/setter pair
sysMetal ↔ MetalList
徽章
getter/setter pair
thankCnt ↔ int
评论感谢数
getter/setter pair
thumbnailURL ↔ String
评论作者头像
getter/setter pair
timeAgo ↔ String
评论经过时间
getter/setter pair
visible ↔ bool
评论是否可见
getter/setter pair
vote ↔ VoteStatus
评论状态
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited