ArticleList class

文章列表

Constructors

ArticleList({dynamic articles, dynamic pagination, dynamic tag})
ArticleList.from(Map<String, dynamic> data)

Properties

hashCode → int
The hash code for this object.
no setterinherited
list ↔ List<ArticleDetail>
getter/setter pair
pagination ↔ Pagination
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tag ↔ ArticleTag?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited