ArticleListType class

帖子列表查询类型

Constructors

ArticleListType()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

values → List<String>
no setter

Static Methods

toCode(String type) → String

Constants

Good → const String
点赞
Hot → const String
热门
Perfect → const String
优选,需包含标签
Recent → const String
最近
Reply → const String
最近回复