ArticlePost class

发帖信息

Constructors

ArticlePost({String title = '', String content = '', String tags = '', bool commentable = false, bool notifyFollowers = false, int type = 0, int showInList = 0, String? rewardContent, String? rewardPoint, bool? anonymous, int? offerPoint})
ArticlePost.from(Map<String, dynamic> data)

Properties

anonymous ↔ bool?
是否匿名
getter/setter pair
commentable ↔ bool
是否允许评论
getter/setter pair
content ↔ String
帖子内容
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
notifyFollowers ↔ bool
是否通知帖子关注者
getter/setter pair
offerPoint ↔ int?
提问悬赏积分
getter/setter pair
rewardContent ↔ String?
打赏内容
getter/setter pair
rewardPoint ↔ String?
打赏积分
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showInList ↔ int
是否在列表展示
getter/setter pair
tags ↔ String
帖子标签
getter/setter pair
title ↔ String
帖子标题
getter/setter pair
type ↔ int
帖子类型,ArticleType
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited