CommentPost class

评论发布

Constructors

CommentPost({String articleId = '', bool isAnonymous = false, bool isVisible = false, String content = '', String replyId = ''})
CommentPost.from(Map<String, dynamic> json)

Properties

articleId ↔ String
文章 Id
getter/setter pair
content ↔ String
评论内容
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isAnonymous ↔ bool
是否匿名评论
getter/setter pair
isVisible ↔ bool
评论是否楼主可见
getter/setter pair
replyId ↔ String
回复评论 Id
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited