Pagination class

分页信息

Constructors

Pagination({int count = 0, List<int> pageNums = const []})
Pagination.from(Map<String, dynamic> data)

Properties

count ↔ int
总分页数
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
pageNums ↔ List<int>
建议分页页码
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited