ChatNotice class

私聊通知

Constructors

ChatNotice({required String command, required String userId, String? preview, String? senderAvatar, String? senderUserName})
ChatNotice.from(Map<String, dynamic> data)

Properties

command ↔ String
命令
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
preview ↔ String?
预览内容
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
senderAvatar ↔ String?
发送者头像
getter/setter pair
senderUserName ↔ String?
发送者用户名
getter/setter pair
userId ↔ String
发送用户 ID
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited