ChatRoomData class

聊天室消息

Constructors

ChatRoomData(String type, dynamic data)

Properties

barrager ↔ BarragerMsg?
getter/setter pair
custom ↔ CustomMsg?
getter/setter pair
discuss ↔ CustomMsg?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
msg ↔ ChatRoomMessage?
getter/setter pair
online ↔ OnlineMsg?
消息内容 OnlineMsg | discussMsg | RevokeMsg | ChatRoomMessage | RedPacketStatusMsg | BarragerMsg | CustomMsg
getter/setter pair
revoke ↔ CustomMsg?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ RedPacketStatusMsg?
getter/setter pair
type ↔ String
消息类型,
getter/setter pair
unknown ↔ dynamic
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited