ChatSource class

消息来源

Constructors

ChatSource({String client = ClientType.Dart, String version = 'latest'})
ChatSource.from(String? client)

Properties

client ↔ String
客户端类型
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version ↔ String
客户端版本
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → dynamic
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited