WeatherMsg class

Constructors

WeatherMsg({String city = '', String description = '', List<WeatherMsgData> data = const []})
WeatherMsg.from(Map data)

Properties

city ↔ String
getter/setter pair
data ↔ List<WeatherMsgData>
getter/setter pair
description ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → dynamic
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getData(Map data) → List<WeatherMsgData>