WeatherMsgData class

Constructors

WeatherMsgData({String date = '', String code = '', double min = 0, double max = 0})
WeatherMsgData.from(Map data)

Properties

code ↔ String
getter/setter pair
date ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
max ↔ double
getter/setter pair
min ↔ double
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → dynamic
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited