MoFishGame class

摸鱼大闯关信息

Constructors

MoFishGame({String userName = '', String stage = '', int time = 0})
MoFishGame.from(Map data)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stage ↔ String
getter/setter pair
time ↔ int
getter/setter pair
userName ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → dynamic
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited