NoticeAt class

提到我通知

Constructors

NoticeAt({String oId = '', int dataType = 0, String userName = '', String avatarURL = '', String content = '', bool hasRead = false, String createTime = ''})
NoticeAt.from(Map<String, dynamic> data)

Properties

avatarURL ↔ String
用户头像
getter/setter pair
content ↔ String
通知内容
getter/setter pair
createTime ↔ String
创建时间
getter/setter pair
dataType ↔ int
数据类型
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hasRead ↔ bool
是否已读
getter/setter pair
oId ↔ String
通知 id
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userName ↔ String
用户名
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited