NoticeComment class

评论/回帖通知

Constructors

NoticeComment({String oId = '', String title = '', String author = '', String thumbnailURL = '', ArticleType type = ArticleType.Normal, bool perfect = false, String content = '', String sharpURL = '', bool hasRead = false, String createTime = ''})
NoticeComment.from(Map<String, dynamic> data)

Properties

author ↔ String
文章作者
getter/setter pair
content ↔ String
评论内容
getter/setter pair
createTime ↔ String
评论时间
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hasRead ↔ bool
是否已读
getter/setter pair
oId ↔ String
通知 id
getter/setter pair
perfect ↔ bool
是否精选
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sharpURL ↔ String
评论地址
getter/setter pair
thumbnailURL ↔ String
作者头像
getter/setter pair
title ↔ String
文章标题
getter/setter pair
type ↔ ArticleType
文章类型
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited