NoticeCount class

通知数

Constructors

NoticeCount({required bool notifyStatus, required int count, required int reply, required int point, required int at, required int broadcast, required int sysAnnounce, required int newFollower, required int following, required int commented})
NoticeCount.from(Map<String, dynamic> data)

Properties

at ↔ int
未读 @ 通知数
getter/setter pair
broadcast ↔ int
未读同城通知数
getter/setter pair
commented ↔ int
未读评论通知数
getter/setter pair
count ↔ int
未读通知数
getter/setter pair
following ↔ int
未读关注通知数
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
newFollower ↔ int
未读关注者通知数
getter/setter pair
notifyStatus ↔ bool
用户是否启用 Web 通知
getter/setter pair
point ↔ int
未读积分通知数
getter/setter pair
reply ↔ int
未读回复通知数
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sysAnnounce ↔ int
未读系统通知数
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → dynamic
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited