NoticeFollow class

关注通知

Constructors

NoticeFollow({String oId = '', String url = '', int dataType = 0, String title = '', String author = '', String content = '', bool isComment = false, String thumbnailURL = '', int commentCnt = 0, bool perfect = false, List<ArticleTag> tagObjs = const [], String tags = '', int type = 0, bool hasRead = false, String createTime = ''})
NoticeFollow.from(Map<String, dynamic> data)

Properties

author ↔ String
作者
getter/setter pair
commentCnt ↔ int
文章评论数
getter/setter pair
content ↔ String
通知内容
getter/setter pair
createTime ↔ String
通知创建时间
getter/setter pair
dataType ↔ int
数据类型
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hasRead ↔ bool
是否已读
getter/setter pair
isComment ↔ bool
是否评论
getter/setter pair
oId ↔ String
通知 Id
getter/setter pair
perfect ↔ bool
是否精选
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tagObjs ↔ List<ArticleTag>
文章标签列表
getter/setter pair
tags ↔ String
文章标签
getter/setter pair
thumbnailURL ↔ String
作者头像
getter/setter pair
title ↔ String
文章标题
getter/setter pair
type ↔ int
文章类型
getter/setter pair
url ↔ String
文章地址
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited