NoticeMsgType class

通知消息类型

Constructors

NoticeMsgType()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

values → List<String>
no setter

Constants

refresh → const String
刷新通知数,需调用 Notice.count 获取明细
warnBroadcast → const String
全局公告