NoticeSystem class

系统通知数据

Constructors

NoticeSystem({String oId = '', String userId = '', String dataId = '', int dataType = 0, String description = '', bool hasRead = false, String createTime = ''})
NoticeSystem.from(Map<String, dynamic> data)

Properties

createTime ↔ String
创建日期
getter/setter pair
dataId ↔ String
数据 Id
getter/setter pair
dataType ↔ int
数据类型
getter/setter pair
description ↔ String
消息描述
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hasRead ↔ bool
是否已读
getter/setter pair
oId ↔ String
消息的 oId
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId ↔ String
用户 Id
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited