RedPacketBase class

红包基本信息

Constructors

RedPacketBase({int count = 0, GestureType? gesture = GestureType.Rock, int got = 0, String msg = '', String userName = '', String avatarURL = ''})
RedPacketBase.from(Map data)

Properties

avatarURL ↔ String
用户头像
getter/setter pair
count ↔ int
数量
getter/setter pair
gesture ↔ GestureType?
猜拳类型
getter/setter pair
got ↔ int
领取数
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
msg ↔ String
祝福语
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userName ↔ String
发送者用户名
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → dynamic
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited