RedPacketGot class

红包领取者信息

Constructors

RedPacketGot({String userId = '', String userName = '', String avatar = '', int money = 0, String time = ''})
RedPacketGot.from(Map data)

Properties

avatar ↔ String
用户头像
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
money ↔ int
领取到的积分
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
time ↔ String
领取积分时间
getter/setter pair
userId ↔ String
用户 id
getter/setter pair
userName ↔ String
用户名
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → dynamic
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited