RedPacketMessage class

红包历史信息

Constructors

RedPacketMessage({String type = '', int count = 0, int got = 0, int money = 0, String msg = '', String senderId = '', List<String> recivers = const [], List<RedPacketGot> who = const []})
RedPacketMessage.from(Map data)

Properties

count ↔ int
红包数
getter/setter pair
gesture ↔ GestureType?
出拳,猜拳红包有效
getter/setter pair
got ↔ int
领取数
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
money ↔ int
内含积分
getter/setter pair
msg ↔ String
祝福语
getter/setter pair
recivers ↔ List<String>
接收者,专属红包有效
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
senderId ↔ String
发送者 id
getter/setter pair
type ↔ String
红包类型,使用 RedPacketType.toName(type) 获取名称
getter/setter pair
who ↔ List<RedPacketGot>
已领取者列表
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → dynamic
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited