RedPacketStatusMsg class

红包状态信息

Constructors

RedPacketStatusMsg({String oId = '', int count = 0, int got = 0, String whoGive = '', String whoGot = '', String avatarURL20 = '', String avatarURL48 = '', String avatarURL210 = ''})
RedPacketStatusMsg.from(Map data)

Properties

avatarURL20 ↔ String
领取者头像 20x20
getter/setter pair
avatarURL210 ↔ String
领取者头像 210x210
getter/setter pair
avatarURL48 ↔ String
领取者头像 48x48
getter/setter pair
count ↔ int
红包个数
getter/setter pair
got ↔ int
已领取数量
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
oId ↔ String
对应红包消息 oId
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
whoGive ↔ String
发送者信息
getter/setter pair
whoGot ↔ String
领取者信息
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → dynamic
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited