Log class

服务器日志

Constructors

Log({String key1 = '', String key2 = '', String data = '', bool isPublic = false, String key3 = '', String oId = '', String type = ''})
Log.from(Map<String, dynamic> json)

Properties

data ↔ String
内容
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isPublic ↔ bool
是否公开
getter/setter pair
key1 ↔ String
操作时间
getter/setter pair
key2 ↔ String
IP
getter/setter pair
key3 ↔ String
操作类型
getter/setter pair
oId ↔ String
唯一标识
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String
类型
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → dynamic
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited