LoginData class

登录账户信息

Constructors

LoginData({String username = '', String passwd = '', String? mfaCode})
LoginData.from(Map<String, dynamic> data)

Properties

hashCode → int
The hash code for this object.
no setterinherited
mfaCode ↔ String?
二次验证码
getter/setter pair
passwd ↔ String
密码
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
username ↔ String
用户名
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → dynamic
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited