PreRegisterInfo class

预注册账户信息

Constructors

PreRegisterInfo({String username = '', String phone = '', String? invitecode, String captcha = ''})
PreRegisterInfo.from(Map<String, dynamic> data)

Properties

captcha ↔ String
验证码
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
invitecode ↔ String?
邀请码
getter/setter pair
phone ↔ String
手机号
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
username ↔ String
用户名
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → dynamic
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited