Report class

举报数据

Constructors

Report({required String reportDataId, ReportDataType reportDataType = ReportDataType.chatroom, ReportType reportType = ReportType.advertise, required String reportMemo})
Report.from(Map<String, dynamic> json)

Properties

hashCode → int
The hash code for this object.
no setterinherited
reportDataId ↔ String
举报对象的 oId
getter/setter pair
reportDataType ↔ ReportDataType
举报数据的类型
getter/setter pair
reportMemo ↔ String
举报的理由
getter/setter pair
reportType ↔ ReportType
举报的类型
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → dynamic
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited