UserLite class

最近注册用户信息

Constructors

UserLite({String userName = '', String userNickname = ''})
UserLite.from(Map<String, dynamic> data)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userName ↔ String
getter/setter pair
userNickname ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → dynamic
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited