UserVipInfo class

Constructors

UserVipInfo({bool jointVip = false, String color = '', bool underline = false, bool metal = false, int autoCheckin = 0, bool bold = false, String oId = '', bool state = false, String userId = '', String lvCode = '', int expiresAt = 0, int createdAt = 0, int updatedAt = 0})
UserVipInfo.from(Map data)

Properties

autoCheckin ↔ int
getter/setter pair
bold ↔ bool
getter/setter pair
color ↔ String
getter/setter pair
createdAt ↔ int
getter/setter pair
createdDate → dynamic
no setter
expiresAt ↔ int
getter/setter pair
expiresDate → dynamic
no setter
hashCode → int
The hash code for this object.
no setterinherited
isVip → dynamic
no setter
jointVip ↔ bool
getter/setter pair
lvCode ↔ String
getter/setter pair
metal ↔ bool
getter/setter pair
oId ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ bool
getter/setter pair
underline ↔ bool
getter/setter pair
updatedAt ↔ int
getter/setter pair
updatedDate → dynamic
no setter
userId ↔ String
getter/setter pair
VipName → dynamic
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited