MembershipConfig class

VIP 配置参数

Constructors

MembershipConfig({bool? jointVip, String? color, bool? underline, bool? metal, int? autoCheckin, bool? bold, int? checkinCard})
MembershipConfig.from(Map<String, dynamic> data)

Properties

autoCheckin ↔ int?
自动签到(0 关闭,1 开启)
getter/setter pair
bold ↔ bool?
是否加粗
getter/setter pair
checkinCard ↔ int?
免签卡数量
getter/setter pair
color ↔ String?
颜色主题
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
jointVip ↔ bool?
是否开启联合会员
getter/setter pair
metal ↔ bool?
是否显示徽章
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
underline ↔ bool?
是否显示下划线
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited