MembershipUserConfig class

VIP 用户配置信息(用于批量查询)

Constructors

MembershipUserConfig({required String userId, required String configJson, MembershipConfig? config})
MembershipUserConfig.from(Map<String, dynamic> data)

Properties

config MembershipConfig?
解析后的配置对象
getter/setter pair
configJson String
昵称样式配置JSON字符串
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId String
用户ID
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited