Metal class

徽章信息

Inheritance

Constructors

Metal({required MetalAttr attr, required String name, required String description, String data = '', String? enable})
Metal.from(Map<String, dynamic> metal)

Properties

attr ↔ MetalAttr
徽章属性
getter/setter pairinherited
data ↔ String
徽章数据
getter/setter pairinherited
description ↔ String
徽章描述
getter/setter pairinherited
enable ↔ String?
是否佩戴
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
icon → String
徽章地址(不含文字)
no setter
name ↔ String
徽章名
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String
完整徽章地址(含文字)
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → dynamic
override
toString() → String
A string representation of this object.
override
toUrl([dynamic includeText = true]) → dynamic
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited