MetalBase class

徽章基础信息

Implementers

Constructors

MetalBase({required MetalAttr attr, required String name, required String description, String data = ''})
MetalBase.from(Map<String, dynamic> metal)

Properties

attr ↔ MetalAttr
徽章属性
getter/setter pair
data ↔ String
徽章数据
getter/setter pair
description ↔ String
徽章描述
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String
徽章名
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → dynamic
toString() → String
A string representation of this object.
inherited
toUrl([dynamic includeText = true]) → dynamic

Operators

operator ==(Object other) → bool
The equality operator.
inherited