UpdateUserParams class

Constructors

UpdateUserParams({String? userNickname, String? userTags, String? userURL, String? userIntro, String? mbti})
UpdateUserParams.from(Map data)

Properties

hashCode → int
The hash code for this object.
no setterinherited
mbti ↔ String?
MBTI
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userIntro ↔ String?
个性签名
getter/setter pair
userNickname ↔ String?
昵称
getter/setter pair
userTags ↔ String?
用户标签
getter/setter pair
userURL ↔ String?
个人主页 URL
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → dynamic
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited