MembershipInfo class
用户 VIP 信息
Constructors
- MembershipInfo({required String oId, required String lvCode, required int state, required String expiresAt, required String configJson})
-
MembershipInfo.from(Map<
String, dynamic> data)
Properties
- configJson ↔ String
-
昵称样式配置JSON
getter/setter pair
- expiresAt ↔ String
-
过期时间 ISO格式
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- lvCode ↔ String
-
VIP等级和类型,如 VIP2_MONTH
getter/setter pair
- oId ↔ String
-
用户ID
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state ↔ int
-
状态:0=非VIP,非0=VIP状态
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited